package com.siwei.rsmonitoring.service;

import com.siwei.rsmonitoring.domain.vo.QkCountVo;
import com.siwei.system.api.domain.SysDept;

import java.util.List;
import java.util.Set;

public interface IQkZtService {

    public QkCountVo selectQkZtCount(QkCountVo vo);
    public QkCountVo selectypdtbcfQkZtCount(QkCountVo vo);
    public QkCountVo selectpdjgQkZtCount(QkCountVo vo);

    public  List<QkCountVo>  selectQkZtCountList(QkCountVo vo);
    public  List<QkCountVo>  selectQkZtJzCountList(QkCountVo vo);
    public  List<QkCountVo>  selectQkZtXjshCountList(QkCountVo vo);
    public  List<QkCountVo>  selectQkZtSjshCountList(QkCountVo vo);
    public  List<QkCountVo>  selectQkZtSJJSHCountList(QkCountVo vo);
    public  List<QkCountVo>  selectpdjdQkZtCountList(QkCountVo vo);
    public  List<QkCountVo>  selectpdjgQkZtCountList(QkCountVo vo);
    public  List<QkCountVo>  selectjghzQkZtCountList(QkCountVo vo);


    public Set<String> selectXzqdmUserList(Long checkXzqdm);

    public List<SysDept> selectXzqdmUseTree(Long checkXzqdm);
}
