package com.siwei.rsmonitoring.controller;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.siwei.common.core.constant.HttpStatus;
import com.siwei.common.core.utils.StringUtils;
import com.siwei.common.core.web.controller.BaseController;
import com.siwei.common.core.web.domain.AjaxResult;
import com.siwei.common.core.web.page.TableDataInfo;
import com.siwei.rsmonitoring.domain.TDkjbxx;
import com.siwei.rsmonitoring.domain.vo.DataCountVo;
import com.siwei.rsmonitoring.domain.vo.QkCountVo;
import com.siwei.rsmonitoring.service.IQkZtService;
import com.siwei.rsmonitoring.service.ITDkjbxxService;
import com.siwei.rsmonitoring.service.ITDkjbxxYwypService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Set;

/**
 * 总体情况统计
 *
 * @author siwei
 * @date 2025-01-20
 */
@RestController
@RequestMapping("/qkzt")
public class QkZtController extends BaseController {
    @Autowired
    private IQkZtService iQkZtService;

    //汇总
    @PostMapping("/count")
    public AjaxResult hctbCount(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtCount(countVo));
    }

    //监测图斑
    @PostMapping("/jctb/list")
    public AjaxResult hctbCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtCountList(countVo));
    }


    //外业举证图斑
    @PostMapping("/jz/list")
    public AjaxResult jzCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtJzCountList(countVo));
    }

    //县级
    @PostMapping("/xjsh/list")
    public AjaxResult xjshCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtXjshCountList(countVo));
    }

    //市级
    @PostMapping("/sjsh/list")
    public AjaxResult sjshCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtSjshCountList(countVo));
    }

    //省级
    @PostMapping("/sjjsh/list")
    public AjaxResult sjjshCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectQkZtSJJSHCountList(countVo));
    }

    //判定进度
    @PostMapping("/pdjd/list")
    public AjaxResult pdjdCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectpdjdQkZtCountList(countVo));
    }

    //已盘定图斑拆分后汇总
    @PostMapping("/ypdtbcf/count")
    public AjaxResult ypdtbcfCount(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectypdtbcfQkZtCount(countVo));
    }

    //判定结果情况 汇总
    @PostMapping("/pdjg/count")
    public AjaxResult pdjgCount(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectpdjgQkZtCount(countVo));
    }

    //判定结果情况 汇总
    @PostMapping("/pdjg/list")
    public AjaxResult pdjgCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectpdjgQkZtCountList(countVo));
    }

    //结果汇总表
    @PostMapping("/jghz/list")
    public AjaxResult jghzCountList(@RequestBody QkCountVo countVo) {
        return success(iQkZtService.selectjghzQkZtCountList(countVo));
    }





}
